@@ -11,6 +11,8 @@
 #include "IpMessengerImpl.h"
 #include "ipmsg.h"
 
+using namespace ipmsg;
+
 #define WINCOMPAT
 
 #ifdef HAVE_OPENSSL
@@ -377,13 +379,13 @@ IpMessengerAgentImpl::EncryptMsg( const HostListItem& host, unsigned char *optBu
 	snprintf( (char *)out_buf, ob_len, "%lx:", pubKeyMethod | shareKeyMethod );
 	for( int i = 0; i < enc_key_len; i++ ) {
 		char pout_hex[3];
-		snprintf( pout_hex, 3, "%02x", (unsigned char)enc_key[i] );
+		IpMsgUCharToHexString( pout_hex, (unsigned char)enc_key[i] );
 		strcat( (char *)out_buf, pout_hex );
 	}
 	strcat( (char *)out_buf, PACKET_DELIMITER_STRING );
 	for( int i = 0; i < o_len; i++ ) {
 		char pout_hex[3];
-		snprintf( pout_hex, 3, "%02x", (unsigned char)enc_buf[i] );
+		IpMsgUCharToHexString( pout_hex, (unsigned char)enc_buf[i] );
 		strcat( (char *)out_buf, pout_hex );
 	}
 	*enc_optBufLen = strlen( (char *)out_buf );
@@ -418,7 +420,7 @@ IpMessengerAgentImpl::EncryptMsg( const HostListItem& host, unsigned char *optBu
  * @retval false:沽
  */
 bool
-IpMessengerAgentImpl::DecryptMsg( const Packet &packet, string& msg )
+IpMessengerAgentImpl::DecryptMsg( const Packet &packet, std::string& msg )
 {
 #ifdef HAVE_OPENSSL
 	EVP_CIPHER_CTX ctx;
@@ -458,7 +460,7 @@ IpMessengerAgentImpl::DecryptMsg( const Packet &packet, string& msg )
 		free( file_info );
 		return false;
 	}
-	string ekey = token;
+	std::string ekey = token;
 
 	token = nextpos;
 	token = strtok_r( token, PACKET_DELIMITER_STRING, &nextpos );
@@ -467,9 +469,9 @@ IpMessengerAgentImpl::DecryptMsg( const Packet &packet, string& msg )
 		free( file_info );
 		return false;
 	}
-	string emsg = token;
+	std::string emsg = token;
 
-	string esign = "";
+	std::string esign = "";
 	token = nextpos;
 	token = strtok_r( token, PACKET_DELIMITER_STRING, &nextpos );
 	if ( token != NULL ) {
@@ -746,7 +748,7 @@ IpMessengerAgentImpl::DecryptMsg( const Packet &packet, string& msg )
 		memcpy( &optBuf[tmp_len+1], file_info, file_info_len );
 		tmp_len += ( file_info_len + 1 );
 	}
-	msg = string( (char *)optBuf, tmp_len );
+	msg = std::string( (char *)optBuf, tmp_len );
 	IpMsgPrintBuf( "optBuf(2):", (char *)optBuf, tmp_len );
 	free( optBuf );
 	free( file_info );
