@@ -10,6 +10,8 @@
 #include "IpMessenger.h"
 #include "IpMessengerImpl.h"
 
+using namespace ipmsg;
+
 //NICκ
 #define IFR_MAX 20
 
@@ -89,7 +91,7 @@ IpMessengerAgent::StartNetwork()
  * @parem nics ưоݤȤNICΥ٥
  */
 void
-IpMessengerAgent::StartNetwork( const vector<NetworkInterface>& nics )
+IpMessengerAgent::StartNetwork( const std::vector<NetworkInterface>& nics )
 {
 	ipmsgImpl->StartNetwork( nics );
 }
@@ -120,7 +122,7 @@ IpMessengerAgent::RestartNetwork()
  * @parem nics ưоݤȤNICΥ٥
  */
 void
-IpMessengerAgent::RestartNetwork( const vector<NetworkInterface>& nics )
+IpMessengerAgent::RestartNetwork( const std::vector<NetworkInterface>& nics )
 {
 	ipmsgImpl->RestartNetwork( nics );
 }
@@ -130,7 +132,7 @@ IpMessengerAgent::RestartNetwork( const vector<NetworkInterface>& nics )
  * @retval СΥɥ쥹
  */
 FileNameConverter *
-IpMessengerAgent::GetFileNameConverter()
+IpMessengerAgent::GetFileNameConverter() const
 {
 	return ipmsgImpl->GetFileNameConverter();
 }
@@ -140,7 +142,7 @@ IpMessengerAgent::GetFileNameConverter()
  * @param conv СΥɥ쥹ưŪ˺Τǡå˺ƤϤʤʤҡ׾˺뤳ȡ
  */
 void
-IpMessengerAgent::SetFileNameConverter( FileNameConverter *conv )
+IpMessengerAgent::SetFileNameConverter( const FileNameConverter *conv )
 {
 	ipmsgImpl->SetFileNameConverter( conv );
 }
@@ -150,7 +152,7 @@ IpMessengerAgent::SetFileNameConverter( FileNameConverter *conv )
  * @retval ٥ȥ֥ȤΥɥ쥹
  */
 HostListComparator *
-IpMessengerAgent::GetSortHostListComparator()
+IpMessengerAgent::GetSortHostListComparator() const
 {
 	return ipmsgImpl->GetSortHostListComparator();
 }; 
@@ -160,7 +162,7 @@ IpMessengerAgent::GetSortHostListComparator()
  * @param comparator ۥȥꥹӥ֥ȤΥɥ쥹ưŪ˺Τǡå˺ƤϤʤʤҡ׾˺뤳ȡ
  */
 void
-IpMessengerAgent::SetSortHostListComparator( HostListComparator *comparator )
+IpMessengerAgent::SetSortHostListComparator( const HostListComparator *comparator )
 {
 	ipmsgImpl->SetSortHostListComparator( comparator );
 }
@@ -170,7 +172,7 @@ IpMessengerAgent::SetSortHostListComparator( HostListComparator *comparator )
  * @retval ٥ȥ֥ȤΥɥ쥹
  */
 IpMessengerEvent *
-IpMessengerAgent::GetEventObject()
+IpMessengerAgent::GetEventObject() const
 {
 	return ipmsgImpl->GetEventObject();
 }; 
@@ -180,7 +182,7 @@ IpMessengerAgent::GetEventObject()
  * @param evt ٥ȥ֥ȤΥɥ쥹ưŪ˺Τǡå˺ƤϤʤʤҡ׾˺뤳ȡ
  */
 void
-IpMessengerAgent::SetEventObject( IpMessengerEvent *evt )
+IpMessengerAgent::SetEventObject( const IpMessengerEvent *evt )
 {
 	ipmsgImpl->SetEventObject( evt );
 }
@@ -190,7 +192,7 @@ IpMessengerAgent::SetEventObject( IpMessengerEvent *evt )
  * @param nics ͥåȥ󥿡եΰ
  */
 void
-IpMessengerAgent::GetNetworkInterfaceInfo( vector<NetworkInterface>& nics )
+IpMessengerAgent::GetNetworkInterfaceInfo( std::vector<NetworkInterface>& nics )
 {
 	IpMessengerAgentImpl::GetNetworkInterfaceInfo( nics );
 }
@@ -199,7 +201,7 @@ IpMessengerAgent::GetNetworkInterfaceInfo( vector<NetworkInterface>& nics )
  * ʥӥΡˡ
  */
 void
-IpMessengerAgent::Login( string nickname, string groupName )
+IpMessengerAgent::Login( std::string nickname, std::string groupName )
 {
 	ipmsgImpl->Login( nickname, groupName );
 }
@@ -238,7 +240,7 @@ IpMessengerAgent::UpdateHostList()
  * @retval ѤԺߥ⡼ɤ֤
  */
 bool
-IpMessengerAgent::IsAbsence()
+IpMessengerAgent::IsAbsence() const
 {
 	return ipmsgImpl->IsAbsence();
 }
@@ -257,7 +259,7 @@ IpMessengerAgent::ResetAbsence()
  * @param absenceModes AbsenceMode֥ȤΥ٥ʼưʣ󥳡ǥб뤿
  */
 void
-IpMessengerAgent::SetAbsence( string encoding, vector<AbsenceMode> absenceModes )
+IpMessengerAgent::SetAbsence( std::string encoding, std::vector<AbsenceMode> absenceModes )
 {
 	ipmsgImpl->SetAbsence( encoding, absenceModes );
 }
@@ -272,8 +274,8 @@ IpMessengerAgent::SetAbsence( string encoding, vector<AbsenceMode> absenceModes
  * @param IsNoLogging ˻ĤʤʤȤ侩
  * @param opt ץ
  */
-SentMessage
-IpMessengerAgent::SendMsg( HostListItem host, string msg, bool isSecret, bool isLockPassword, int hostCountAtSameTime, bool IsNoLogging, unsigned long opt )
+bool
+IpMessengerAgent::SendMsg( HostListItem host, std::string msg, bool isSecret, bool isLockPassword, int hostCountAtSameTime, bool IsNoLogging, unsigned long opt )
 {
 	return ipmsgImpl->SendMsg( host, msg, isSecret, isLockPassword, hostCountAtSameTime, IsNoLogging, opt );
 }
@@ -289,8 +291,8 @@ IpMessengerAgent::SendMsg( HostListItem host, string msg, bool isSecret, bool is
  * @param IsNoLogging ˻ĤʤʤȤ侩
  * @param opt ץ
  */
-SentMessage
-IpMessengerAgent::SendMsg( HostListItem host, string msg, bool isSecret, AttachFile& file, bool isLockPassword, int hostCountAtSameTime, bool IsNoLogging, unsigned long opt )
+bool
+IpMessengerAgent::SendMsg( HostListItem host, std::string msg, bool isSecret, AttachFile& file, bool isLockPassword, int hostCountAtSameTime, bool IsNoLogging, unsigned long opt )
 {
 	return ipmsgImpl->SendMsg( host, msg, isSecret, file, isLockPassword, hostCountAtSameTime, IsNoLogging, opt );
 }
@@ -306,8 +308,8 @@ IpMessengerAgent::SendMsg( HostListItem host, string msg, bool isSecret, AttachF
  * @param IsNoLogging ˻ĤʤʤȤ侩
  * @param opt ץ
  */
-SentMessage
-IpMessengerAgent::SendMsg( HostListItem host, string msg, bool isSecret, AttachFileList& files, bool isLockPassword, int hostCountAtSameTime, bool IsNoLogging, unsigned long opt )
+bool
+IpMessengerAgent::SendMsg( HostListItem host, std::string msg, bool isSecret, AttachFileList& files, bool isLockPassword, int hostCountAtSameTime, bool IsNoLogging, unsigned long opt )
 {
 	return ipmsgImpl->SendMsg( host, msg, isSecret, files, isLockPassword, hostCountAtSameTime, IsNoLogging, opt );
 }
@@ -326,7 +328,7 @@ IpMessengerAgent::ClearBroadcastAddress()
  * @param addr ϿѤΥ֥ɥ㥹ȥɥ쥹
  */
 void
-IpMessengerAgent::DeleteBroadcastAddress( string addr )
+IpMessengerAgent::DeleteBroadcastAddress( std::string addr )
 {
 	ipmsgImpl->DeleteBroadcastAddress( addr );
 }
@@ -336,7 +338,7 @@ IpMessengerAgent::DeleteBroadcastAddress( string addr )
  * @param addr Ͽ֥ɥ㥹ȥɥ쥹
  */
 void
-IpMessengerAgent::AddBroadcastAddress( string addr )
+IpMessengerAgent::AddBroadcastAddress( std::string addr )
 {
 	ipmsgImpl->AddBroadcastAddress( addr );
 }
@@ -346,7 +348,7 @@ IpMessengerAgent::AddBroadcastAddress( string addr )
  * @param host оݤΥۥ
  * @retval оݥۥȤΥС
  */
-string
+std::string
 IpMessengerAgent::GetInfo( HostListItem& host )
 {
 	return ipmsgImpl->GetInfo( host );
@@ -357,7 +359,7 @@ IpMessengerAgent::GetInfo( HostListItem& host )
  * @param host оݤΥۥ
  * @retval оݥۥȤԺʸ
  */
-string
+std::string
 IpMessengerAgent::GetAbsenceInfo( HostListItem& host )
 {
 	return ipmsgImpl->GetAbsenceInfo( host );
@@ -367,7 +369,7 @@ IpMessengerAgent::GetAbsenceInfo( HostListItem& host )
  * ݻΥۥȥꥹȤ饰롼ץꥹȤ롣
  * @retval 롼ץꥹ
  */
-vector<GroupItem>
+std::vector<GroupItem>
 IpMessengerAgent::GetGroupList()
 {
 	return ipmsgImpl->GetGroupList();
@@ -450,7 +452,7 @@ IpMessengerAgent::GetSentMessages()
  * @retval ѥåꥹȤΥԡ
  */
 SentMessageList
-IpMessengerAgent::CloneSentMessages()
+IpMessengerAgent::CloneSentMessages() const
 {
 	return ipmsgImpl->CloneSentMessages();
 }
@@ -459,8 +461,8 @@ IpMessengerAgent::CloneSentMessages()
  * ̾Υå
  * @retval ̾
  */
-string
-IpMessengerAgent::LoginName()
+std::string
+IpMessengerAgent::LoginName() const
 {
 	return ipmsgImpl->LoginName();
 }
@@ -469,18 +471,38 @@ IpMessengerAgent::LoginName()
  * ۥ̾Υå
  * @retval ۥ̾
  */
-string
-IpMessengerAgent::HostName()
+std::string
+IpMessengerAgent::HostName() const
 {
 	return ipmsgImpl->HostName();
 }
 
+/**
+ * ǥեȥݡȤΥå
+ * @retval ǥեȥݡ
+ */
+int
+IpMessengerAgent::DefaultPortNo() const
+{
+	return ipmsgImpl->DefaultPortNo();
+}
+
+/**
+ * ǥեȥݡȤΥå
+ * @param defaultPortNo ǥեȥݡ
+ */
+void
+IpMessengerAgent::setDefaultPortNo( const int defaultPortNo )
+{
+	ipmsgImpl->setDefaultPortNo( defaultPortNo );
+}
+
 /**
  * 륢åפΥå
  * @retval 륢å
  */
 bool
-IpMessengerAgent::IsDialup()
+IpMessengerAgent::IsDialup() const
 {
 	return ipmsgImpl->IsDialup();
 }
@@ -490,7 +512,7 @@ IpMessengerAgent::IsDialup()
  * @param isDialup 륢å
  */
 void
-IpMessengerAgent::setIsDialup( bool isDialup )
+IpMessengerAgent::setIsDialup( const bool isDialup )
 {
 	ipmsgImpl->setIsDialup( isDialup );
 }
@@ -500,7 +522,7 @@ IpMessengerAgent::setIsDialup( bool isDialup )
  * @retval ɻ˥ե뤬ѹ줿˶ػߤ뤫ɤΥե饰
  */
 bool
-IpMessengerAgent::AbortDownloadAtFileChanged()
+IpMessengerAgent::AbortDownloadAtFileChanged() const
 {
 	return ipmsgImpl->AbortDownloadAtFileChanged();
 }
@@ -510,7 +532,7 @@ IpMessengerAgent::AbortDownloadAtFileChanged()
  * @param isAbort ɻ˥ե뤬ѹ줿˶ػߤ뤫ɤΥե饰
  */
 void
-IpMessengerAgent::setAbortDownloadAtFileChanged( bool isAbort )
+IpMessengerAgent::setAbortDownloadAtFileChanged( const bool isAbort )
 {
 	ipmsgImpl->setAbortDownloadAtFileChanged( isAbort );
 }
@@ -520,7 +542,7 @@ IpMessengerAgent::setAbortDownloadAtFileChanged( bool isAbort )
  * @retval å¸뤫ɤΥե饰
  */
 bool
-IpMessengerAgent::SaveSentMessage()
+IpMessengerAgent::SaveSentMessage() const
 {
 	return ipmsgImpl->SaveSentMessage();
 }
@@ -530,7 +552,7 @@ IpMessengerAgent::SaveSentMessage()
  * @param isSave å¸뤫ɤΥե饰
  */
 void
-IpMessengerAgent::setSaveSentMessage( bool isSave )
+IpMessengerAgent::setSaveSentMessage( const bool isSave )
 {
 	ipmsgImpl->setSaveSentMessage( isSave );
 }
@@ -540,7 +562,7 @@ IpMessengerAgent::setSaveSentMessage( bool isSave )
  * @retval å¸뤫ɤΥե饰
  */
 bool
-IpMessengerAgent::SaveRecievedMessage()
+IpMessengerAgent::SaveRecievedMessage() const
 {
 	return ipmsgImpl->SaveRecievedMessage();
 }
@@ -550,11 +572,29 @@ IpMessengerAgent::SaveRecievedMessage()
  * @param isSave å¸뤫ɤΥե饰
  */
 void
-IpMessengerAgent::setSaveRecievedMessage( bool isSave )
+IpMessengerAgent::setSaveRecievedMessage( const bool isSave )
 {
 	ipmsgImpl->setSaveRecievedMessage( isSave );
 }
 
+/**
+ * Ź沽˼ԤåʤɤΥե饰Υå
+ * @retval Ź沽˼ԤåʤɤΥե饰
+ */
+bool IpMessengerAgent::NoSendMessageOnEncryptionFailed() const
+{
+	return ipmsgImpl->NoSendMessageOnEncryptionFailed();
+}
+
+/**
+ * Ź沽˼ԤåʤɤΥե饰Υå
+ * @param isSave Ź沽˼ԤåʤɤΥե饰
+ */
+void IpMessengerAgent::setNoSendMessageOnEncryptionFailed( const bool isNoSend )
+{
+	return ipmsgImpl->setNoSendMessageOnEncryptionFailed( isNoSend );
+}
+
 /**
  * ®٤򻻽Ф롣
  * @retval ®١ʥХȡáˡ
@@ -569,7 +609,7 @@ DownloadInfo::getSpeed()
  * ®ʸ롣
  * @retval ®ʸñ̡áˡ:1 B/sec, 2.00KB/sec, 3.00 MB/sec, 4.00 GB/sec, 5.00 TB/sec
  */
-string
+std::string
 DownloadInfo::getSpeedString()
 {
 	return DownloadInfo::getUnitSizeString( ( long long )getSpeed() ) + "/sec";
@@ -579,7 +619,7 @@ DownloadInfo::getSpeedString()
  * ʸ롣
  * @retval ʸñ̡ˡ:1 B, 2.00KB, 3.00 MB, 4.00 GB, 5.00 TB
  */
-string
+std::string
 DownloadInfo::getSizeString()
 {
 	return DownloadInfo::getUnitSizeString( Size() );
@@ -595,7 +635,7 @@ DownloadInfo::getSizeString()
  * ʸ롣
  * @retval ʸñ̡ˡ:1 B, 2.00KB, 3.00 MB, 4.00 GB, 5.00 TB
  */
-string
+std::string
 DownloadInfo::getUnitSizeString( long long size )
 {
 	long double dsize = (long double)size;
@@ -616,4 +656,64 @@ DownloadInfo::getUnitSizeString( long long size )
 	snprintf( buf, sizeof( buf ), "%lld B", size );
 	return buf;
 }
+
+/**
+ * IPɥ쥹ꤷͥåȥɥ쥹֥ɥ㥹ȥɥ쥹Ʒ׻롣
+ * @param val IPɥ쥹ʸ
+ */
+void
+NetworkInterface::setIpAddress( const std::string val )
+{
+	_IpAddress = val;
+	inet_pton( AF_INET, val.c_str(), (void *)&_NativeIpAddress );
+	recalc();
+}
+/**
+ * ͥåȥޥꤷͥåȥɥ쥹֥ɥ㥹ȥɥ쥹Ʒ׻롣
+ * @param val ͥåȥޥʸ
+ */
+void
+NetworkInterface::setNetMask( const std::string val )
+{
+	_NetMask = val;
+	inet_pton( AF_INET, val.c_str(), (void *)&_NativeNetMask );
+	recalc();
+}
+/**
+ * IPɥ쥹(ͥƥ)ꤷͥåȥɥ쥹֥ɥ㥹ȥɥ쥹Ʒ׻롣
+ * @param val IPɥ쥹
+ */
+void
+NetworkInterface::setNativeIpAddress( const struct in_addr val )
+{
+	_NativeIpAddress = val;
+	char ipAddrBuf[IP_ADDR_MAX_SIZE];
+	_IpAddress = inet_ntop( AF_INET, &val, ipAddrBuf, sizeof( ipAddrBuf ) );
+	recalc();
+}
+/**
+ * ͥåȥޥ(ͥƥ)ꤷͥåȥɥ쥹֥ɥ㥹ȥɥ쥹Ʒ׻롣
+ * @param val ͥåȥޥ
+ */
+void
+NetworkInterface::setNativeNetMask( const struct in_addr val )
+{
+	_NativeNetMask = val;
+	char netMaskBuf[IP_ADDR_MAX_SIZE];
+	_NetMask = inet_ntop( AF_INET, &val, netMaskBuf, sizeof( netMaskBuf ) );
+	recalc();
+}
+/**
+ * ͥåȥɥ쥹֥ɥ㥹ȥɥ쥹׻롣
+ */
+void
+NetworkInterface::recalc()
+{
+	char buf[IP_ADDR_MAX_SIZE];
+	_NativeNetworkAddress.s_addr = _NativeIpAddress.s_addr & _NativeNetMask.s_addr;
+	_NetworkAddress = inet_ntop( AF_INET, &_NativeNetworkAddress, buf, sizeof( buf ) );
+
+	_NativeBroadcastAddress = GetBroadcastAddress( _NativeNetworkAddress, _NativeNetMask );
+	_BroadcastAddress = inet_ntop( AF_INET, &_NativeBroadcastAddress, buf, sizeof( buf ) );
+}
 //end of source
