@@ -26,10 +26,10 @@
 #endif
 
 #include <string>
-#include <queue>
 #include <map>
 #include <vector>
-using namespace std;
+
+namespace ipmsg {
 
 /**
  * ɤ߹ѥץѥƥ
@@ -88,9 +88,9 @@ class Packet{
 		IPMSG_PROPERTY( unsigned long, CommandMode );
 		IPMSG_PROPERTY( unsigned long, CommandOption );
 		IPMSG_PROPERTY( time_t, Recieved );
-		IPMSG_PROPERTY( string, HostName );
-		IPMSG_PROPERTY( string, UserName );
-		IPMSG_PROPERTY( string, Option );
+		IPMSG_PROPERTY( std::string, HostName );
+		IPMSG_PROPERTY( std::string, UserName );
+		IPMSG_PROPERTY( std::string, Option );
 		IPMSG_PROPERTY( struct sockaddr_in, Addr );
 		IPMSG_PROPERTY( int, TcpSocket );
 };
@@ -100,16 +100,25 @@ class Packet{
  **/
 class NetworkInterface {
 	public:
-		IPMSG_PROPERTY( string, DeviceName );
-		IPMSG_PROPERTY( string, IpAddress );
-		IPMSG_PROPERTY( string, NetMask );
-		IPMSG_PROPERTY( string, NetworkAddress );
-		IPMSG_PROPERTY( string, BroadcastAddress );
-		IPMSG_PROPERTY( in_addr_t, NativeIpAddress );
-		IPMSG_PROPERTY( in_addr_t, NativeNetMask );
-		IPMSG_PROPERTY( in_addr_t, NativeNetworkAddress );
-		IPMSG_PROPERTY( in_addr_t, NativeBroadcastAddress );
+		IPMSG_PROPERTY( std::string, DeviceName );
+		IPMSG_READONLY_PROPERTY( std::string, IpAddress );
+		IPMSG_READONLY_PROPERTY( std::string, NetMask );
+		IPMSG_READONLY_PROPERTY( std::string, NetworkAddress );
+		IPMSG_READONLY_PROPERTY( std::string, BroadcastAddress );
+		IPMSG_READONLY_PROPERTY( struct in_addr, NativeIpAddress );
+		IPMSG_READONLY_PROPERTY( struct in_addr, NativeNetMask );
+		IPMSG_READONLY_PROPERTY( struct in_addr, NativeNetworkAddress );
+		IPMSG_READONLY_PROPERTY( struct in_addr, NativeBroadcastAddress );
 		IPMSG_PROPERTY( int, PortNo );
+		NetworkInterface( std::string deviceName ):_DeviceName( deviceName ){};
+		NetworkInterface(){};
+	public:
+		void setIpAddress( const std::string val );
+		void setNetMask( const std::string val );
+		void setNativeIpAddress( const struct in_addr val );
+		void setNativeNetMask( const struct in_addr val );
+	private:
+		void recalc();
 };
 
 /**
@@ -117,8 +126,8 @@ class NetworkInterface {
  **/
 class GroupItem{
 	public:
-		IPMSG_PROPERTY( string, GroupName );
-		IPMSG_PROPERTY( string, EncodingName );
+		IPMSG_PROPERTY( std::string, GroupName );
+		IPMSG_PROPERTY( std::string, EncodingName );
 };
 
 /**
@@ -126,20 +135,20 @@ class GroupItem{
  **/
 class HostListItem{
 	public:
-		IPMSG_PROPERTY( string, Version );
-		IPMSG_PROPERTY( string, AbsenceDescription );
-		IPMSG_PROPERTY( string, UserName );
-		IPMSG_PROPERTY( string, HostName );
+		IPMSG_PROPERTY( std::string, Version );
+		IPMSG_PROPERTY( std::string, AbsenceDescription );
+		IPMSG_PROPERTY( std::string, UserName );
+		IPMSG_PROPERTY( std::string, HostName );
 		IPMSG_PROPERTY( unsigned long, CommandNo );
-		IPMSG_PROPERTY( string, IpAddress );
-		IPMSG_PROPERTY( string, Nickname );
-		IPMSG_PROPERTY( string, GroupName );
-		IPMSG_PROPERTY( string, EncodingName );
-		IPMSG_PROPERTY( string, Priority );
+		IPMSG_PROPERTY( std::string, IpAddress );
+		IPMSG_PROPERTY( std::string, Nickname );
+		IPMSG_PROPERTY( std::string, GroupName );
+		IPMSG_PROPERTY( std::string, EncodingName );
+		IPMSG_PROPERTY( std::string, Priority );
 		IPMSG_PROPERTY( unsigned long, PortNo );
 		IPMSG_PROPERTY( unsigned long, EncryptionCapacity );
-		IPMSG_PROPERTY( string, PubKeyHex );
-		IPMSG_PROPERTY( string, EncryptMethodHex );
+		IPMSG_PROPERTY( std::string, PubKeyHex );
+		IPMSG_PROPERTY( std::string, EncryptMethodHex );
 		bool IsLocalHost() const;
 		bool IsFileAttachSupport() const;
 		bool IsEncryptSupport() const;
@@ -164,7 +173,7 @@ class HostListComparator{
 		 * @retval 0:host1host2
 		 * @retval +n:host2礭
 		 */
-		virtual int compare( vector<HostListItem>::iterator host1, vector<HostListItem>::iterator host2 )=0;
+		virtual int compare( std::vector<HostListItem>::iterator host1, std::vector<HostListItem>::iterator host2 )=0;
 };
 
 /**
@@ -180,7 +189,7 @@ class HostListDefaultComparator: public HostListComparator{
 		 * @retval 0:host1host2
 		 * @retval +n:host2礭
 		 */
-		virtual int compare( vector<HostListItem>::iterator host1, vector<HostListItem>::iterator host2 ){
+		virtual int compare( std::vector<HostListItem>::iterator host1, std::vector<HostListItem>::iterator host2 ){
 			return host1->Compare( *host2 );
 		};
 };
@@ -195,27 +204,28 @@ class HostList{
 		IPMSG_PROPERTY( time_t, PrevTry );
 		IPMSG_PROPERTY( int, RetryCount );
 		void AddHost( const HostListItem& host );
-		void Delete( vector<HostListItem>::iterator &it );
-		void DeleteHost( string hostname );
-		vector<HostListItem>::iterator FindHostByAddress( string addr );
-		vector<HostListItem>::iterator FindHostByHostName( string hostName );
+		void Delete( std::vector<HostListItem>::iterator &it );
+		void DeleteHostByAddress( std::string addr );
+		std::vector<HostListItem>::iterator FindHostByAddress( std::string addr );
+		std::vector<HostListItem>::iterator FindHostByHostName( std::string hostName );
 		static HostListItem CreateHostListItemFromPacket( const Packet& packet );
-		vector<HostListItem>::iterator begin();
-		vector<HostListItem>::iterator end();
+		std::vector<HostListItem>::iterator begin();
+		std::vector<HostListItem>::iterator end();
 		int size() const;
 		void clear();
-		string ToString( int start, const struct sockaddr_in *addr );
+		std::string ToString( int start, const struct sockaddr_in *addr );
 		void sort( HostListComparator *comparator );
 		HostList();
 		HostList( const HostList& other );
 		~HostList();
 		HostList& operator=( const HostList& other );
+		std::vector<GroupItem> GetGroupList();
 	private:
 		void qsort( HostListComparator *comparator, int left, int right );
 		void Lock( const char *pos ) const;
 		void Unlock( const char *pos ) const;
 		void CopyFrom( const HostList& other );
-		vector<HostListItem>items;
+		std::vector<HostListItem>items;
 		pthread_mutex_t hostListMutex;
 };
 
@@ -225,8 +235,8 @@ class HostList{
  **/
 class FileNameConverter {
 	public:
-		virtual string ConvertNetworkToLocal( string original_file_name ) = 0;
-		virtual string ConvertLocalToNetwork( string original_file_name ) = 0;
+		virtual std::string ConvertNetworkToLocal( std::string original_file_name ) = 0;
+		virtual std::string ConvertLocalToNetwork( std::string original_file_name ) = 0;
 };
 
 /**
@@ -234,8 +244,8 @@ class FileNameConverter {
  **/
 class NullFileNameConverter:public FileNameConverter {
 	public:
-		virtual string ConvertNetworkToLocal( string original_file_name ){ return original_file_name; };
-		virtual string ConvertLocalToNetwork( string original_file_name ){ return original_file_name; };
+		virtual std::string ConvertNetworkToLocal( std::string original_file_name ){ return original_file_name; };
+		virtual std::string ConvertLocalToNetwork( std::string original_file_name ){ return original_file_name; };
 };
 
 /**
@@ -243,13 +253,13 @@ class NullFileNameConverter:public FileNameConverter {
  **/
 class AttachFile{
 	public:
-		map<string, vector<unsigned long> >::iterator beginExtAttrs() { return _ExtAttrs.begin(); };
-		map<string, vector<unsigned long> >::iterator endExtAttrs() { return _ExtAttrs.end(); };
-		void addExtAttrs( string key, unsigned long val ){ _ExtAttrs[key].push_back( val ); };
+		std::map<std::string, std::vector<unsigned long> >::iterator beginExtAttrs() { return _ExtAttrs.begin(); };
+		std::map<std::string, std::vector<unsigned long> >::iterator endExtAttrs() { return _ExtAttrs.end(); };
+		void addExtAttrs( std::string key, unsigned long val ){ _ExtAttrs[key].push_back( val ); };
 		IPMSG_PROPERTY( int, FileId );
-		IPMSG_PROPERTY( string, FullPath );
-		IPMSG_PROPERTY( string, FileName );
-		IPMSG_PROPERTY( string, Location );
+		IPMSG_PROPERTY( std::string, FullPath );
+		IPMSG_PROPERTY( std::string, FileName );
+		IPMSG_PROPERTY( std::string, Location );
 		IPMSG_PROPERTY( long long, FileSize );
 		IPMSG_PROPERTY( long long, TransSize );
 		IPMSG_PROPERTY( bool, IsDownloaded );
@@ -262,10 +272,10 @@ class AttachFile{
 		bool IsDirectory() const;
 		void GetLocalFileInfo();
 	private:
-		map<string, vector<unsigned long> > _ExtAttrs;
+		std::map<std::string, std::vector<unsigned long> > _ExtAttrs;
 	public:
 		static AttachFile AnalyzeHeader( char *buf, FileNameConverter *conv );
-		static string CreateDirFullPath( const vector<string>& dirstack );
+		static std::string CreateDirFullPath( const std::vector<std::string>& dirstack );
 };
 
 /**
@@ -277,14 +287,14 @@ class DownloadInfo{
 		IPMSG_PROPERTY( time_t, Time );
 		IPMSG_PROPERTY( long, FileCount );
 		IPMSG_PROPERTY( bool, Processing );
-		IPMSG_PROPERTY( string, LocalFileName );
+		IPMSG_PROPERTY( std::string, LocalFileName );
 		IPMSG_PROPERTY_REF( AttachFile, File );
 
 		DownloadInfo():_Size( 0ULL ), _Time( 0 ), _FileCount( 0L ), _LocalFileName(""){};
 		long double getSpeed();
-		string getSpeedString();
-		string getSizeString();
-		static string getUnitSizeString( long long size );
+		std::string getSpeedString();
+		std::string getSizeString();
+		static std::string getUnitSizeString( long long size );
 };
 
 /**
@@ -293,14 +303,14 @@ class DownloadInfo{
 class AttachFileList{
 	public:
 		void AddFile( const AttachFile& file );
-		vector<AttachFile>::iterator begin();
-		vector<AttachFile>::iterator end();
+		std::vector<AttachFile>::iterator begin();
+		std::vector<AttachFile>::iterator end();
 		int size() const;
 		void clear();
-		vector<AttachFile>::iterator erase( vector<AttachFile>::iterator item );
-		vector<AttachFile>::iterator erase( const AttachFile& item );
-		vector<AttachFile>::iterator FindByFullPath( const string& fullPath );
-		vector<AttachFile>::iterator FindByFileId( int file_id );
+		std::vector<AttachFile>::iterator erase( std::vector<AttachFile>::iterator item );
+		std::vector<AttachFile>::iterator erase( const AttachFile& item );
+		std::vector<AttachFile>::iterator FindByFullPath( const std::string& fullPath );
+		std::vector<AttachFile>::iterator FindByFileId( int file_id );
 		AttachFileList();
 		AttachFileList( const AttachFileList& other );
 		~AttachFileList();
@@ -309,7 +319,7 @@ class AttachFileList{
 		void Lock( const char *pos ) const;
 		void Unlock( const char *pos ) const;
 		void CopyFrom( const AttachFileList& other );
-		vector<AttachFile> files;
+		std::vector<AttachFile> files;
 		pthread_mutex_t filesMutex;
 };
 
@@ -321,7 +331,7 @@ class IpMessengerEvent;
 class RecievedMessage{
 	public:
 		IPMSG_PROPERTY( Packet, MessagePacket );
-		IPMSG_PROPERTY( string, Message );
+		IPMSG_PROPERTY( std::string, Message );
 		IPMSG_PROPERTY( time_t, Recieved );
 		IPMSG_PROPERTY( bool, IsConfirmed );
 		IPMSG_PROPERTY( bool, IsSecret );
@@ -336,14 +346,14 @@ class RecievedMessage{
 		RecievedMessage();
 		RecievedMessage( const RecievedMessage& other );
 		RecievedMessage& operator=( const RecievedMessage& other );
-		bool DownloadFile( AttachFile &file, string saveFileNameFullPath, DownloadInfo& info, FileNameConverter *conv=NULL, void *data=NULL );
-		bool DownloadDir( AttachFile &file, string saveDirName, string saveBaseDir, DownloadInfo& info, FileNameConverter *conv=NULL, void *data=NULL );
+		bool DownloadFile( AttachFile &file, std::string saveFileNameFullPath, DownloadInfo& info, FileNameConverter *conv=NULL, void *data=NULL );
+		bool DownloadDir( AttachFile &file, std::string saveDirName, std::string saveBaseDir, DownloadInfo& info, FileNameConverter *conv=NULL, void *data=NULL );
 	private:
 		void CopyFrom( const RecievedMessage& other );
-		bool DownloadFilePrivate( IpMessengerEvent *event, AttachFile &file, string saveFileNameFullPath, DownloadInfo& info, FileNameConverter *conv=NULL, void *data=NULL );
-		bool DownloadDirPrivate( IpMessengerEvent *event, AttachFile &file, string saveDirName, string saveBaseDir, DownloadInfo& info, FileNameConverter *conv=NULL, void *data=NULL );
-		string GetFormalDir( string dirName );
-		string GetSaveDir( string saveName, string saveBaseDir );
+		bool DownloadFilePrivate( IpMessengerEvent *event, AttachFile &file, std::string saveFileNameFullPath, DownloadInfo& info, FileNameConverter *conv=NULL, void *data=NULL );
+		bool DownloadDirPrivate( IpMessengerEvent *event, AttachFile &file, std::string saveDirName, std::string saveBaseDir, DownloadInfo& info, FileNameConverter *conv=NULL, void *data=NULL );
+		std::string GetFormalDir( std::string dirName );
+		std::string GetSaveDir( std::string saveName, std::string saveBaseDir );
 };
 
 /**
@@ -351,9 +361,9 @@ class RecievedMessage{
  **/
 class RecievedMessageList {
 	public:
-		vector<RecievedMessage>::iterator begin();
-		vector<RecievedMessage>::iterator end();
-		vector<RecievedMessage>::iterator erase( vector<RecievedMessage>::iterator item );
+		std::vector<RecievedMessage>::iterator begin();
+		std::vector<RecievedMessage>::iterator end();
+		std::vector<RecievedMessage>::iterator erase( std::vector<RecievedMessage>::iterator item );
 		void append( const RecievedMessage &item );
 		int size() const;
 		void clear();
@@ -365,7 +375,7 @@ class RecievedMessageList {
 		void Lock( const char *pos ) const;
 		void Unlock( const char *pos ) const;
 		void CopyFrom( const RecievedMessageList& other );
-		vector<RecievedMessage> messages;
+		std::vector<RecievedMessage> messages;
 		pthread_mutex_t messagesMutex;
 };
 
@@ -377,7 +387,7 @@ class SentMessage{
 		IPMSG_PROPERTY( struct sockaddr_in, To );
 		IPMSG_PROPERTY( HostListItem, Host );
 		IPMSG_PROPERTY( unsigned long, PacketNo );
-		IPMSG_PROPERTY( string, Message );
+		IPMSG_PROPERTY( std::string, Message );
 		IPMSG_PROPERTY( time_t, Sent );
 		IPMSG_PROPERTY( time_t, PrevTry );
 		IPMSG_PROPERTY( bool, IsRetryMaxOver );
@@ -397,7 +407,7 @@ class SentMessage{
 		SentMessage& operator=( const SentMessage& other );
 		bool isRetryMaxOver() const;
 		bool needSendRetry( time_t tryNow ) const;
-		vector<AttachFile>::iterator FindAttachFileByPacket( const Packet &packet );
+		std::vector<AttachFile>::iterator FindAttachFileByPacket( const Packet &packet );
 	private:
 		void CopyFrom( const SentMessage& other );
 };
@@ -407,15 +417,15 @@ class SentMessage{
  **/
 class SentMessageList {
 	public:
-		vector<SentMessage>::iterator begin();
-		vector<SentMessage>::iterator end();
-		vector<SentMessage>::iterator erase( vector<SentMessage>::iterator item );
-		vector<SentMessage>::iterator FindSentMessageByPacketNo( unsigned long PacketNo );
-		vector<SentMessage>::iterator FindSentMessageByPacket( Packet packet );
+		std::vector<SentMessage>::iterator begin();
+		std::vector<SentMessage>::iterator end();
+		std::vector<SentMessage>::iterator erase( std::vector<SentMessage>::iterator item );
+		std::vector<SentMessage>::iterator FindSentMessageByPacketNo( unsigned long PacketNo );
+		std::vector<SentMessage>::iterator FindSentMessageByPacket( Packet packet );
 		void append( const SentMessage &item );
 		int size() const;
 		void clear();
-		vector<SentMessage> *GetMessageList();
+		std::vector<SentMessage> *GetMessageList();
 		SentMessageList();
 		SentMessageList( const SentMessageList& other );
 		~SentMessageList();
@@ -425,7 +435,7 @@ class SentMessageList {
 		void Lock( const char *pos ) const;
 		void Unlock( const char *pos ) const;
 		void CopyFrom( const SentMessageList& other );
-		vector<SentMessage> messages;
+		std::vector<SentMessage> messages;
 		pthread_mutex_t messagesMutex;
 };
 
@@ -434,9 +444,9 @@ class SentMessageList {
  **/
 class AbsenceMode {
 	public:
-		IPMSG_PROPERTY( string, EncodingName );
-		IPMSG_PROPERTY( string, AbsenceName );
-		IPMSG_PROPERTY( string, AbsenceDescription );
+		IPMSG_PROPERTY( std::string, EncodingName );
+		IPMSG_PROPERTY( std::string, AbsenceName );
+		IPMSG_PROPERTY( std::string, AbsenceDescription );
 };
 
 
@@ -446,6 +456,11 @@ class AbsenceMode {
  **/
 class IpMessengerEvent {
 	public:
+		/**
+		 * ۥȥꥹȥեå奤٥
+		 * @param hostList ۥȥꥹ
+		 */
+		virtual void RefreashHostListAfter( HostList& hostList )=0;
 		/**
 		 * ۥȥꥹȹ奤٥
 		 * @param hostList ۥȥꥹ
@@ -517,31 +532,31 @@ class IpMessengerEvent {
 		virtual bool DownloadError( RecievedMessage& msg, AttachFile& file, DownloadInfo &info, void *data )=0;
 		/**
 		 * ۥȤλθ奤٥
-		 * @param hostList ۥȥꥹ
+		 * @param host ۥ
 		 */
-		virtual void EntryAfter( HostList& hostList )=0;
+		virtual void EntryAfter( HostListItem& host )=0;
 		/**
 		 * ۥȤæθ奤٥
-		 * @param hostList ۥȥꥹ
+		 * @param host ۥ
 		 */
-		virtual void ExitAfter( HostList& hostList )=0;
+		virtual void ExitAfter( HostListItem& host )=0;
 		/**
 		 * Ժߥ⡼ɹ奤٥
-		 * @param hostList ۥȥꥹ
+		 * @param hostList ۥ
 		 */
-		virtual void AbsenceModeChangeAfter( HostList& hostList )=0;
+		virtual void AbsenceModeChangeAfter( HostListItem& host )=0;
 		/**
 		 * С奤٥
 		 * @param host ۥ
 		 * @param version С
 		 */
-		virtual void VersionInfoRecieveAfter( HostListItem &host, string version )=0;
+		virtual void VersionInfoRecieveAfter( HostListItem &host, std::string version )=0;
 		/**
 		 * Ժ߾ܺپ奤٥
 		 * @param host ۥ
 		 * @param absenceDetail Ժ߾ܺپ
 		 */
-		virtual void AbsenceDetailRecieveAfter( HostListItem& host, string absenceDetail )=0;
+		virtual void AbsenceDetailRecieveAfter( HostListItem& host, std::string absenceDetail )=0;
 		/**
 		 * ǥȥ饯
 		 */
@@ -568,7 +583,7 @@ class IpMessengerAgent {
 		/**
 		 * NICξ
 		 **/
-		static void GetNetworkInterfaceInfo( vector<NetworkInterface>& nics );
+		static void GetNetworkInterfaceInfo( std::vector<NetworkInterface>& nics );
 
 		/**
 		 * ֥ɥ㥹ȥɥ쥹ΥꥹȤ򥯥ꥢ
@@ -578,17 +593,17 @@ class IpMessengerAgent {
 		/**
 		 * ֥ɥ㥹ȥɥ쥹ΥꥹȤ饢ɥ쥹
 		 **/
-		void DeleteBroadcastAddress( string addr );
+		void DeleteBroadcastAddress( std::string addr );
 
 		/**
 		 * ֥ɥ㥹ȥɥ쥹ΥꥹȤ˥ɥ쥹ɲ
 		 **/
-		void AddBroadcastAddress( string addr );
+		void AddBroadcastAddress( std::string addr );
 
 		/**
 		 * ΡʻΡ
 		 **/
-		void Login( string nickname, string groupName );
+		void Login( std::string nickname, std::string groupName );
 
 		/**
 		 * ΡæΡ
@@ -608,17 +623,17 @@ class IpMessengerAgent {
 		/**
 		 * åź̵
 		 **/
-		SentMessage SendMsg( HostListItem host, string msg, bool isSecret, bool isLockPassword=false, int hostCountAtSameTime=1, bool IsNoLogging=false, unsigned long opt=0UL );
+		bool SendMsg( HostListItem host, std::string msg, bool isSecret, bool isLockPassword=false, int hostCountAtSameTime=1, bool IsNoLogging=false, unsigned long opt=0UL );
 
 		/**
 		 * åʰźա
 		 **/
-		SentMessage SendMsg( HostListItem host, string msg, bool isSecret, AttachFile& file, bool isLockPassword=false, int hostCountAtSameTime=1, bool IsNoLogging=false, unsigned long opt=0UL );
+		bool SendMsg( HostListItem host, std::string msg, bool isSecret, AttachFile& file, bool isLockPassword=false, int hostCountAtSameTime=1, bool IsNoLogging=false, unsigned long opt=0UL );
 
 		/**
 		 * åʣźա
 		 **/
-		SentMessage SendMsg( HostListItem host, string msg, bool isSecret, AttachFileList& files, bool isLockPassword=false, int hostCountAtSameTime=1, bool IsNoLogging=false, unsigned long opt=0UL );
+		bool SendMsg( HostListItem host, std::string msg, bool isSecret, AttachFileList& files, bool isLockPassword=false, int hostCountAtSameTime=1, bool IsNoLogging=false, unsigned long opt=0UL );
 
 		/**
 		 * Ժ߲
@@ -628,22 +643,22 @@ class IpMessengerAgent {
 		/**
 		 * Ժ
 		 **/
-		void SetAbsence( string encoding, vector<AbsenceMode> absenceModes );
+		void SetAbsence( std::string encoding, std::vector<AbsenceMode> absenceModes );
 
 		/**
 		 * 롼װ
 		 **/
-		vector<GroupItem> GetGroupList();
+		std::vector<GroupItem> GetGroupList();
 
 		/**
 		 * С
 		 **/
-		string GetInfo( HostListItem& host );
+		std::string GetInfo( HostListItem& host );
 
 		/**
 		 * Ժ߾
 		 **/
-		string GetAbsenceInfo( HostListItem& host );
+		std::string GetAbsenceInfo( HostListItem& host );
 
 		/**
 		 * ѥåȤνʥݡѡ
@@ -683,47 +698,47 @@ class IpMessengerAgent {
 		/**
 		 * åꥹȤΥԡμ
 		 **/
-		SentMessageList CloneSentMessages();
+		SentMessageList CloneSentMessages() const;
 
 		/**
 		 * ۥȥꥹӥ֥Ȥ
 		 **/
-		void SetSortHostListComparator( HostListComparator *comparator );
+		void SetSortHostListComparator( const HostListComparator *comparator );
 
 		/**
 		 * ۥȥꥹӥ֥Ȥμ
 		 **/
-		HostListComparator *GetSortHostListComparator();
+		HostListComparator *GetSortHostListComparator() const;
 
 		/**
 		 * ٥ȥ֥Ȥ
 		 **/
-		void SetEventObject( IpMessengerEvent *evt );
+		void SetEventObject( const IpMessengerEvent *evt );
 
 		/**
 		 * ٥ȥ֥Ȥμ
 		 **/
-		IpMessengerEvent *GetEventObject();
+		IpMessengerEvent *GetEventObject() const;
 
 		/**
 		 * ե륳С
 		 **/
-		void SetFileNameConverter( FileNameConverter *conv );
+		void SetFileNameConverter( const FileNameConverter *conv );
 
 		/**
 		 * ե륳Сμ
 		 **/
-		FileNameConverter *GetFileNameConverter();
+		FileNameConverter *GetFileNameConverter() const;
 
 		/**
 		 * Ժߡ
 		 **/
-		bool IsAbsence();
+		bool IsAbsence() const;
 
 		/**
 		 * ͥåȥεưNIC
 		 **/
-		void StartNetwork( const vector<NetworkInterface>& nics );
+		void StartNetwork( const std::vector<NetworkInterface>& nics );
 
 		/**
 		 * ͥåȥεư(ǥե)
@@ -738,7 +753,7 @@ class IpMessengerAgent {
 		/**
 		 * ͥåȥκƵưNIC
 		 **/
-		void RestartNetwork( const vector<NetworkInterface>& nics );
+		void RestartNetwork( const std::vector<NetworkInterface>& nics );
 
 		/**
 		 * ͥåȥκƵư(ǥե)
@@ -748,44 +763,53 @@ class IpMessengerAgent {
 		/**
 		 * ̾
 		 **/
-		string LoginName();
+		std::string LoginName() const;
 
 		/**
 		 * ۥ̾
 		 **/
-		string HostName();
+		std::string HostName() const;
+
+		/**
+		 * ǥեȥݡ
+		 **/
+		int DefaultPortNo() const;
+		void setDefaultPortNo( const int defaultPortNo );
 
 		/**
 		 * 륢å
 		 **/
-		bool IsDialup();
-		void setIsDialup( bool isDialup );
+		bool IsDialup() const;
+		void setIsDialup( const bool isDialup );
 
 		/**
 		 * ե뤬ѹ줿ɤǤ
 		 **/
-		bool AbortDownloadAtFileChanged();
-		void setAbortDownloadAtFileChanged( bool isAbort );
-		/* ߴΰ(0.1.0) */
-		bool GetAbortDownloadAtFileChanged(){ return AbortDownloadAtFileChanged(); };
-		void SetAbortDownloadAtFileChanged( bool isAbort ){ setAbortDownloadAtFileChanged( isAbort ); };
+		bool AbortDownloadAtFileChanged() const;
+		void setAbortDownloadAtFileChanged( const bool isAbort );
 
 		/**
 		 * å򵭲
 		 **/
-		bool SaveSentMessage();
-		void setSaveSentMessage( bool isSave );
+		bool SaveSentMessage() const;
+		void setSaveSentMessage( const bool isSave );
 
 		/**
 		 * å򵭲
 		 **/
-		bool SaveRecievedMessage();
-		void setSaveRecievedMessage( bool isSave );
+		bool SaveRecievedMessage() const;
+		void setSaveRecievedMessage( const bool isSave );
 
+		/**
+		 * Ź沽˼Ԥåʤ
+		 **/
+		bool NoSendMessageOnEncryptionFailed() const;
+		void setNoSendMessageOnEncryptionFailed( const bool isNoSend );
 	private:
 		IpMessengerAgent();
 		~IpMessengerAgent();
 		IpMessengerAgentImpl *ipmsgImpl;
 };
 
+}; // namespace ipmsg
 #endif
