@@ -10,7 +10,8 @@
 #include "IpMessenger.h"
 #include "IpMessengerImpl.h"
 #include "ipmsg.h"
-using namespace std;
+
+using namespace ipmsg;
 
 /**
  * 󥹥ȥ饯
@@ -143,7 +144,7 @@ RecievedMessageList::Unlock( const char *pos ) const
  * ѥåꥹȤƬ򼨤ƥ졼֤
  * @retval ѥåꥹȤƬ򼨤ƥ졼
  */
-vector<RecievedMessage>::iterator
+std::vector<RecievedMessage>::iterator
 RecievedMessageList::begin()
 {
 	return messages.begin();
@@ -153,7 +154,7 @@ RecievedMessageList::begin()
  * ѥåꥹȤܣ򼨤ƥ졼֤
  * @retval ѥåꥹȤܣ򼨤ƥ졼
  */
-vector<RecievedMessage>::iterator
+std::vector<RecievedMessage>::iterator
 RecievedMessageList::end()
 {
 	return messages.end();
@@ -164,11 +165,11 @@ RecievedMessageList::end()
  * @param item оݤμѥå򼨤ƥ졼
  * @retval 줿ѥåμǤ򼨤ƥ졼
  */
-vector<RecievedMessage>::iterator
-RecievedMessageList::erase( vector<RecievedMessage>::iterator item )
+std::vector<RecievedMessage>::iterator
+RecievedMessageList::erase( std::vector<RecievedMessage>::iterator item )
 {
 	Lock( "RecievedMessageList::erase()" );
-	vector<RecievedMessage>::iterator ret = messages.erase( item );
+	std::vector<RecievedMessage>::iterator ret = messages.erase( item );
 	Unlock( "RecievedMessageList::erase()" );
 	return ret;
 }
@@ -216,7 +217,7 @@ RecievedMessageList::clear()
  * </ul>
  */
 bool
-RecievedMessage::DownloadFile( AttachFile &file, string saveFileNameFullPath, DownloadInfo& info, FileNameConverter *conv, void *data )
+RecievedMessage::DownloadFile( AttachFile &file, std::string saveFileNameFullPath, DownloadInfo& info, FileNameConverter *conv, void *data )
 {
 #if defined(DEBUG)
 	printf("DownloadFile\n" );fflush(stdout);
@@ -259,15 +260,13 @@ RecievedMessage::DownloadFile( AttachFile &file, string saveFileNameFullPath, Do
  * </ul>
  */
 bool
-RecievedMessage::DownloadFilePrivate( IpMessengerEvent *event, AttachFile &file, string saveFileNameFullPath, DownloadInfo& info, FileNameConverter *conv, void *data )
+RecievedMessage::DownloadFilePrivate( IpMessengerEvent *event, AttachFile &file, std::string saveFileNameFullPath, DownloadInfo& info, FileNameConverter *conv, void *data )
 {
 	struct sockaddr_in svr_addr;
 	int sock = socket( AF_INET, SOCK_STREAM, 0 );
 
 	svr_addr = MessagePacket().Addr();
 #if defined(DEBUG)
-char ipaddrbuf[IPV4_ADDR_MAX_SIZE];
-printf("IP[%s]\n", inet_ntoa_r( svr_addr.sin_addr.s_addr, ipaddrbuf, sizeof( ipaddrbuf ) ) );fflush(stdout);
 printf("saveFileNameFullPath[%s]\n", saveFileNameFullPath.c_str() );fflush(stdout);
 #endif
 	if ( connect( sock, (struct sockaddr *)&svr_addr, sizeof( svr_addr ) ) != 0 ){
@@ -281,7 +280,10 @@ printf("saveFileNameFullPath[%s]\n", saveFileNameFullPath.c_str() );fflush(stdou
 	char sendBuf[MAX_UDPBUF];
 	int sendBufLen;
 	char optBuf[MAX_UDPBUF];
-	int optBufLen = snprintf( optBuf, sizeof( optBuf ), "%lx:%x:0", MessagePacket().PacketNo(), file.FileId() );
+	size_t optBufLen = snprintf( optBuf, sizeof( optBuf ), "%lx:%x:0", MessagePacket().PacketNo(), file.FileId() );
+	if ( optBufLen <= sizeof( optBuf ) ) {
+		return false;
+	}
 	sendBufLen = agent->CreateNewPacketBuffer( IPMSG_GETFILEDATA,
 												 agent->LoginName(), agent->HostName(),
 												 optBuf, optBufLen,
@@ -369,7 +371,7 @@ printf("saveFileNameFullPath[%s]\n", saveFileNameFullPath.c_str() );fflush(stdou
  * </ul>
  */
 bool
-RecievedMessage::DownloadDir( AttachFile &file, string saveName, string saveBaseDir, DownloadInfo& info, FileNameConverter *conv, void *data )
+RecievedMessage::DownloadDir( AttachFile &file, std::string saveName, std::string saveBaseDir, DownloadInfo& info, FileNameConverter *conv, void *data )
 {
 #if defined(DEBUG)
 	printf("DownloadDir\n" );fflush(stdout);
@@ -410,8 +412,8 @@ RecievedMessage::DownloadDir( AttachFile &file, string saveName, string saveBase
  * @param dirName Υǥ쥯ȥ̾
  * @retval Υǥ쥯ȥ̾
  */
-string
-RecievedMessage::GetFormalDir( string dirName )
+std::string
+RecievedMessage::GetFormalDir( std::string dirName )
 {
 	if ( dirName.at( dirName.length() - 1 ) != '/' ) {
 		return dirName + "/";
@@ -429,8 +431,8 @@ RecievedMessage::GetFormalDir( string dirName )
  * @param saveBaseDir ¸ǥ쥯ȥ̾
  * @retval ¸եʤޤϥǥ쥯ȥ̾
  */
-string
-RecievedMessage::GetSaveDir( string saveName, string saveBaseDir )
+std::string
+RecievedMessage::GetSaveDir( std::string saveName, std::string saveBaseDir )
 {
 	return GetFormalDir( saveBaseDir ) + saveName + "/";
 }
@@ -442,15 +444,15 @@ RecievedMessage::GetSaveDir( string saveName, string saveBaseDir )
  * </ul>
  */
 bool
-RecievedMessage::DownloadDirPrivate( IpMessengerEvent *event, AttachFile &file, string saveName, string saveBaseDir, DownloadInfo& info, FileNameConverter *conv, void *data )
+RecievedMessage::DownloadDirPrivate( IpMessengerEvent *event, AttachFile &file, std::string saveName, std::string saveBaseDir, DownloadInfo& info, FileNameConverter *conv, void *data )
 {
 	if ( conv == NULL ) {
 		info.setProcessing( false );
 		return false;
 	}
 	struct stat st;
-	string saveBaseDirFormal = GetFormalDir( saveBaseDir );
-	string saveDir = GetSaveDir( saveName, saveBaseDir );
+	std::string saveBaseDirFormal = GetFormalDir( saveBaseDir );
+	std::string saveDir = GetSaveDir( saveName, saveBaseDir );
 
 #if defined(DEBUG)
 printf("saveName[%s]\n", saveName.c_str() );fflush(stdout);
@@ -490,7 +492,10 @@ printf("saveBaseDirFormal[%s]\n", saveBaseDirFormal.c_str() );fflush(stdout);
 	char sendBuf[MAX_UDPBUF];
 	int sendBufLen;
 	char optBuf[MAX_UDPBUF];
-	int optBufLen = snprintf( optBuf, sizeof( optBuf ), "%lx:%x", MessagePacket().PacketNo(), file.FileId() );
+	size_t optBufLen = snprintf( optBuf, sizeof( optBuf ), "%lx:%x", MessagePacket().PacketNo(), file.FileId() );
+	if ( optBufLen <= sizeof( optBuf ) ) {
+		return false;
+	}
 	sendBufLen = agent->CreateNewPacketBuffer( IPMSG_GETDIRFILES,
 												 agent->LoginName(), agent->HostName(),
 												 optBuf, optBufLen,
@@ -500,7 +505,7 @@ printf("saveBaseDirFormal[%s]\n", saveBaseDirFormal.c_str() );fflush(stdout);
 	char readbuf[MAX_UDPBUF];
 	bool isEob = false;
 	bool isTopDir = true;
-	vector<string> dir;
+	std::vector<std::string> dir;
 	dir.push_back( saveBaseDir );
 	dir.push_back( saveName );
 
@@ -559,7 +564,7 @@ IpMsgPrintBuf( "DownloadDir:readbuf2", readbuf, read_len );
 		if ( GET_FILETYPE( f.Attr() ) == IPMSG_FILE_REGULAR ) {
 			long long readSize = 0LL;
 			long long wroteSize = 0LL;
-			string FullPath = AttachFile::CreateDirFullPath( dir ) + f.FileName();
+			std::string FullPath = AttachFile::CreateDirFullPath( dir ) + f.FileName();
 			int fd = open( FullPath.c_str(), O_WRONLY | O_CREAT );
 			if ( fd < 0 ){
 				perror("open");
@@ -620,7 +625,7 @@ IpMsgPrintBuf( "DownloadDir:readbuf3", readbuf, read_len );
 				continue;
 			}
 			dir.push_back( f.FileName().c_str() );
-			string FullPath = f.CreateDirFullPath( dir );
+			std::string FullPath = f.CreateDirFullPath( dir );
 			if ( mkdir( FullPath.c_str(), S_IRUSR | S_IWUSR | S_IXUSR | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH ) != 0 ) {
 				perror("mkdir(2)");
 				isEob = true;
